@@ -1,9 +1,6 @@
 from . import chainApproximation
-from . import chainApproximation_c
 from . import digitization
-from . import aggregation_memview
 from . import aggregation
-from . import fabba_agg_memview
 from . import fabba_agg
 from . import load_datasets
 from . import symbolic_representation
